import { AuthenticationResponseJSON, PublicKeyCredentialCreationOptionsJSON, PublicKeyCredentialRequestOptionsJSON, RegistrationResponseJSON } from "@simplewebauthn/typescript-types";
import { HttpsFunction } from "firebase-functions";
interface ClearChallengeFunctionRequest extends UnknownFunctionRequest {
    "type": "clear challenge";
}
interface ClearChallengeFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "type": "clear challenge";
}
interface ClearChallengeFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "missing user doc" | "no action";
    "type": "clear challenge";
}
interface CreateAuthenticationChallengeFunctionRequest extends UnknownFunctionRequest {
    "type": "create authentication challenge";
}
interface CreateAuthenticationChallengeFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "requestOptions": PublicKeyCredentialRequestOptionsJSON;
    "type": "create authentication challenge";
}
interface CreateAuthenticationChallengeFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth";
    "type": "create authentication challenge";
}
interface CreateReauthenticationChallengeFunctionRequest extends UnknownFunctionRequest {
    "type": "create reauthentication challenge";
}
interface CreateReauthenticationChallengeFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "requestOptions": PublicKeyCredentialRequestOptionsJSON;
    "type": "create reauthentication challenge";
}
interface CreateReauthenticationChallengeFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "missing user doc" | "user doc missing passkey fields";
    "type": "create reauthentication challenge";
}
interface CreateRegistrationChallengeFunctionRequest extends UnknownFunctionRequest {
    "name": string;
    "type": "create registration challenge";
}
interface CreateRegistrationChallengeFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "creationOptions": PublicKeyCredentialCreationOptionsJSON;
    "type": "create registration challenge";
}
interface CreateRegistrationChallengeFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "no action";
    "type": "create registration challenge";
}
interface UnknownFunctionRequest {
    "type": "clear challenge" | "create authentication challenge" | "create reauthentication challenge" | "create registration challenge" | "verify authentication" | "verify reauthentication" | "verify registration";
}
interface UnknownFunctionResponse {
    "success": boolean;
    "type": "clear challenge" | "create authentication challenge" | "create reauthentication challenge" | "create registration challenge" | "verify authentication" | "verify reauthentication" | "verify registration";
}
interface UnknownFunctionResponseSuccessful extends UnknownFunctionResponse {
    "success": true;
}
interface UnknownFunctionResponseUnsuccessful extends UnknownFunctionResponse {
    "message": "missing auth" | "missing user doc" | "no action" | "not verified" | "user doc missing challenge field" | "user doc missing passkey fields";
    "success": false;
}
interface VerifyAuthenticationFunctionRequest extends UnknownFunctionRequest {
    "authenticationResponse": AuthenticationResponseJSON;
    "type": "verify authentication";
}
interface VerifyAuthenticationFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "customToken": string;
    "type": "verify authentication";
}
interface VerifyAuthenticationFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "missing user doc" | "no action" | "not verified" | "user doc missing challenge field" | "user doc missing passkey fields";
    "type": "verify authentication";
}
interface VerifyReauthenticationFunctionRequest extends UnknownFunctionRequest {
    "authenticationResponse": AuthenticationResponseJSON;
    "type": "verify reauthentication";
}
interface VerifyReauthenticationFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "customToken": string;
    "type": "verify reauthentication";
}
interface VerifyReauthenticationFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "missing user doc" | "not verified" | "user doc missing challenge field" | "user doc missing passkey fields";
    "type": "verify reauthentication";
}
interface VerifyRegistrationFunctionRequest extends UnknownFunctionRequest {
    "registrationResponse": RegistrationResponseJSON;
    "type": "verify registration";
}
interface VerifyRegistrationFunctionResponseSuccessful extends UnknownFunctionResponseSuccessful {
    "customToken": string;
    "type": "verify registration";
}
interface VerifyRegistrationFunctionResponseUnsuccessful extends UnknownFunctionResponseUnsuccessful {
    "message": "missing auth" | "missing user doc" | "not verified" | "user doc missing challenge field";
    "type": "verify registration";
}
type ClearChallengeFunctionResponse = ClearChallengeFunctionResponseSuccessful | ClearChallengeFunctionResponseUnsuccessful;
type CreateAuthenticationChallengeFunctionResponse = CreateAuthenticationChallengeFunctionResponseSuccessful | CreateAuthenticationChallengeFunctionResponseUnsuccessful;
type CreateReauthenticationChallengeFunctionResponse = CreateReauthenticationChallengeFunctionResponseSuccessful | CreateReauthenticationChallengeFunctionResponseUnsuccessful;
type CreateRegistrationChallengeFunctionResponse = CreateRegistrationChallengeFunctionResponseSuccessful | CreateRegistrationChallengeFunctionResponseUnsuccessful;
type VerifyAuthenticationFunctionResponse = VerifyAuthenticationFunctionResponseSuccessful | VerifyAuthenticationFunctionResponseUnsuccessful;
type VerifyReauthenticationFunctionResponse = VerifyReauthenticationFunctionResponseSuccessful | VerifyReauthenticationFunctionResponseUnsuccessful;
type VerifyRegistrationFunctionResponse = VerifyRegistrationFunctionResponseSuccessful | VerifyRegistrationFunctionResponseUnsuccessful;
export type FunctionRequest = ClearChallengeFunctionRequest | CreateAuthenticationChallengeFunctionRequest | CreateReauthenticationChallengeFunctionRequest | CreateRegistrationChallengeFunctionRequest | VerifyAuthenticationFunctionRequest | VerifyReauthenticationFunctionRequest | VerifyRegistrationFunctionRequest;
export type FunctionResponse = ClearChallengeFunctionResponse | CreateAuthenticationChallengeFunctionResponse | CreateReauthenticationChallengeFunctionResponse | CreateRegistrationChallengeFunctionResponse | VerifyAuthenticationFunctionResponse | VerifyReauthenticationFunctionResponse | VerifyRegistrationFunctionResponse;
export declare const ngxFirebaseWebAuthn: HttpsFunction;
export {};
